//引入消息提示对象和请求处理对象
import msg from '../../utils/msg.js'
import sysrequest from '../../utils/sysrequest.js'

Page({
  /**
   * 页面的初始数据
   */
  data: {
    login_name: '',
    pwd: '',
    isback: false
  },

  /**
   * 页面加载时触发
   * @param {判断是否需要返回上级页面，1返回，0不返回} options 
   */
  onLoad(options) {
    //获取是否返回上级页面
    if (options.isBack === "1") {
      this.setData({ isback: true });
    }

    //判断是否跳转到首页
    if (wx.getStorageSync('user_key')) {
      wx.switchTab({
        url: '/pages/index/index',
      })
    }
  },

  /**
   * 登录名控件录入时触发
   * @param {记录用户录入的登录名} e 
   */
  nameChange(e) {
    //给用户名赋值
    this.setData({ login_name: e.detail });
  },

  /**
   * 焦点离开登录名控件时同步登录名
   */
  blurName(e) {
    this.setData({ login_name: e.detail.value });
  },

  /**
   * 密码控件输入时触发 
   */
  bindPwd(e) {
    //给密码赋值
    this.setData({ pwd: e.detail });
  },

  /**
   * 点击登录按钮时触发
   */
  doLogin() {
    setTimeout(this.login, 500);
  },

  /**
   * 登录
   */
  login() {
    //判断用户名和密码是否合法
    if (this.data.login_name === '') {
      msg.showWarn("用户名不允许为空");
      return;
    } else if (this.data.pwd === '') {
      msg.showWarn("密码不允许为空");
      return;
    }

    //调用登录api，登录程序
    let _this = this;
    wx.showLoading({
      title: '正在登录,请稍等……',
      mask: true
    })
    sysrequest('user/login', 'POST', { userName: this.data.login_name.toUpperCase(), password: this.data.pwd }, 60, (res) => {
      if (res.code === 0) {
        //记录用户key等
        wx.setStorageSync('user_key', res.data.userKey);
        wx.setStorageSync('login_name', _this.data.login_name.toUpperCase());
        wx.setStorageSync('user_name', res.data.userName)
        wx.setStorageSync('is_admin', res.data.isAdmin)
        //判断是否跳回原网页
        if (_this.data.isback) {
          wx.navigateBack({
            delta: 1,
          })
          return;
        }
        //跳转页面
        wx.switchTab({
          url: '/pages/index/index',
        })
      } else {
        wx.hideLoading();
        msg.showErr(res.msg)
      }
    }, (res) => {
      wx.hideLoading();
    });
  }
})